@@ -445,18 +445,6 @@ int MyConnect(dbh_t *sock, char* unixSocket, char* host, char* port,
 	      char* user, char* password, char* dbname, imp_dbh_t *imp_dbh) {
     int portNr;
 
-#ifdef WIN32
-   static int initialized = 0;
-   if (!initialized) {
-       WSADATA wsaData;
-
-       if (WSAStartup(MAKEWORD(1, 1), &wsaData)) {
-	   return FALSE;
-       }
-       initialized = 1;
-   }
-#endif
-
     if (host && !*host) host = NULL;
     if (port && *port) {
         portNr = atoi(port);
@@ -477,12 +465,33 @@ int MyConnect(dbh_t *sock, char* unixSocket, char* host, char* port,
 #ifdef DBD_MYSQL
     {
 	mysql_init(*sock);
-	if (imp_dbh  &&  imp_dbh->compression) {
-	    mysql_options(*sock, MYSQL_OPT_COMPRESS, NULL);
-	}
-	return mysql_real_connect(*sock, host, user, password, dbname,
+	if (imp_dbh) {
+	    SV* sv = DBIc_IMP_DATA(imp_dbh);
+	    if (sv  &&  SvROK(sv)) {
+	        HV* hv = (HV*) SvRV(sv);
+		SV** svp;
+
+		if ((svp = hv_fetch(hv, "mysql_compression", 17, FALSE))  &&
+		    *svp  &&  SvTRUE(*svp)) {
+		    mysql_options(*sock, MYSQL_OPT_COMPRESS, NULL);
+		}
+		if ((svp = hv_fetch(hv, "mysql_read_default_file", 23,
+				    FALSE))  &&
+		    *svp  &&  SvTRUE(*svp)) {
+		  mysql_options(*sock, MYSQL_READ_DEFAULT_FILE,
+				SvPV(*svp, na));
+		}
+		if ((svp = hv_fetch(hv, "mysql_read_default_group", 24,
+				    FALSE))  &&
+		    *svp  &&  SvTRUE(*svp)) {
+		    mysql_options(*sock, MYSQL_READ_DEFAULT_GROUP,
+				  SvPV(*svp, na));
+		}
+	    }
+        }
+        return mysql_real_connect(*sock, host, user, password, dbname,
 				  portNr, unixSocket, 0) ?
-	    TRUE : FALSE;
+	  TRUE : FALSE;
     }
 #else
     {
@@ -577,12 +586,6 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
         dbname = NULL;
     }
 #ifdef DBD_MYSQL
-    if ((svp = hv_fetch(hv, "mysql_compression", 17, FALSE))  &&
-	*svp  &&  SvTRUE(*svp)) {
-        imp_dbh->compression = 1;
-    } else {
-        imp_dbh->compression = 0;
-    }
     if ((svp = hv_fetch(hv, "mysql_socket", 12, FALSE))  &&
         *svp  &&  SvTRUE(*svp)) {
         unixSocket = SvPV(*svp, na);
@@ -898,6 +901,11 @@ SV* dbd_db_FETCH_attrib(SV* dbh, imp_dbh_t* imp_dbh, SV* keysv) {
 	    return info ? sv_2mortal(newSVpv(info, strlen(info))) : &sv_undef;
 	}
 	break;
+      case 'm':
+	if (kl == 14  &&  strEQ(key, "mysql_insertid")) {
+	    return sv_2mortal(newSViv(mysql_insert_id(imp_dbh->svsock)));
+	}
+	break;
 #endif
       case 'p':
 	if (kl == 9  &&  strEQ(key, "protoinfo")) {
@@ -1318,7 +1326,7 @@ AV* dbd_st_fetch(SV* sth, imp_sth_t* imp_sth) {
 	    STRLEN len = strlen(col);
 #endif
 	    if (ChopBlanks) {
-		while(len && isspace(col[len-1])) {
+		while(len && col[len-1] == ' ') {
 		    --len;
 		}
 	    }
