@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.03_05';
+$VERSION = '2.03_06';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -121,48 +121,6 @@ sub connect {
     DBD::mysql->_OdbcParse($dsn, $privateAttrHash,
 				  ['database', 'host', 'port']);
 
-    if (my $file = $privateAttrHash->{'mysql_configfile'}) {
-	require Symbol;
-	my $fh = Symbol::gensym();
-	if (!open($fh, "<$file")) {
-	    DBI::set_err($drh, "Unable to open config file $file: $!");
-	    return undef;
-	}
-	my $inSection;
-	while (defined(my $line = <$fh>)) {
-	    if ($line =~ /^\[(.*?)\]/) {
-		if ($inSection) {
-		    last;
-		} elsif ($1 eq 'perl'  ||  $1 eq 'client') {
-		    $inSection = 1;
-		}
-	    } elsif ($line =~ /^\s*(.*?)\s*=\s*(.*?)\s*$/) {
-		my $var = $1; my $val = $2;
-		if ($var eq 'host'  ||  $var eq 'hostname') {
-		    if (!$privateAttrHash->{'host'}) {
-			$privateAttrHash->{'host'} = $val;
-		    }
-		} elsif ($var eq 'password') {
-		    if (!$password) {
-			$password = $privateAttrHash->{'password'} = $val;
-		    }
-		} elsif ($var eq 'port') {
-		    if (!$privateAttrHash->{'port'}) {
-			$privateAttrHash->{'port'} = $val;
-		    }
-		} elsif ($var eq 'socket') {
-		    if (!$privateAttrHash->{'mysql_socket'}) {
-			$privateAttrHash->{'mysql_socket'} = $val;
-		    }
-		} elsif ($var eq 'user') {
-		    if (!$username) {
-			$username = $privateAttrHash->{'user'} = $val;
-		    }
-		}
-	    }
-	}
-    }
-
     if (!defined($this = DBI::_new_dbh($drh, {}, $privateAttrHash))) {
 	return undef;
     }
@@ -370,7 +328,6 @@ Interface (DBI)
 
     $driver = "mysql";
     $dsn = "DBI:$driver:database=$database;host=$hostname;port=$port";
-    if ($compression) { $dsn .= ";mysql_compression=1"; }
 
     $dbh = DBI->connect($dsn, $user, $password);
 
@@ -439,8 +396,6 @@ of the I<Msql-Mysql-modules> package.
     $dsn = "DBI:mysql:database=$database;host=$hostname";
     $dsn = "DBI:mysql:database=$database;host=$hostname;port=$port";
 
-    if ($compression) { $dsn .= ";mysql_compression=1"; }
-
     $dbh = DBI->connect($dsn, $user, $password);
 
 A C<database> must always be specified.
@@ -481,6 +436,39 @@ As of MySQL 3.22.3, a new feature is supported: If your DSN contains
 the option "mysql_compression=1", then the communication between client
 and server will be compressed.
 
+=item mysql_read_default_file
+
+=item mysql_read_default_group
+
+These options can be used to read a config file like /etc/my.cnf or
+~/.my.cnf. By default MySQL's C client library doesn't use any config
+files unlike the client programs (mysql, mysqladmin, ...) that do, but
+outside of the C client library. Thus you need to explicitly request
+reading a config file, as in
+
+    $dsn = "DBI:mysql:test;mysql_read_default_file=/home/joe/my.cnf";
+    $dbh = DBI->connect($dsn, $user, $password)
+
+The option mysql_read_default_group can be used to specify the default
+group in the config file: Usually this is the I<client> group, but
+see the following example:
+
+    [perl]
+    host=perlhost
+
+    [client]
+    host=localhost
+
+If you read this config file, then you'll be typically connected to
+I<localhost>. However, by using
+
+    $dsn = "DBI:mysql:test;mysql_read_default_group=perl;"
+        . "mysql_read_default_file=/home/joe/my.cnf";
+    $dbh = DBI->connect($dsn, $user, $password);
+
+you'll be connected to I<perlhost>. See the (missing :-) documentation
+of the C function mysql_options() for details.
+
 =item mysql_socket
 
 As of MySQL 3.21.15, it is possible to choose the Unix socket that is
@@ -522,6 +510,8 @@ the only reason why we still support C<ListDBs>. :-(
 
 =item B<ListTables>
 
+*WARNING*: This method is obsolete due to DBI's $dbh->table_info().
+
     @tables = $dbh->func('_ListTables');
 
 Once connected to the desired database on the desired mysql or mSQL
@@ -538,6 +528,7 @@ an empty list is returned.
       }
 
 
+
 =item B<ListFields>
 
 Deprecated, see L</COMPATIBILITY ALERT> below. Used to be equivalent
@@ -647,8 +638,10 @@ handles (read only):
 
     $infoString = $dbh->{'info'};
     $threadId = $dbh->{'thread_id'};
+    $insertId = $dbh->{'mysql_insertid'}
 
-These correspond to mysql_info() and mysql_tread_id(), respectively.
+These correspond to mysql_info(), mysql_thread_id() and mysql_insertid(),
+respectively.
 
 
 =head1 STATEMENT HANDLES
@@ -719,7 +712,8 @@ have impact on the I<max_length> attribute.
 
 MySQL has the ability to choose unique key values automatically. If this
 happened, the new ID will be stored in this attribute. This attribute
-is not valid for DBD::mSQL.
+is not valid for DBD::mSQL. An alternative way for accessing this attribute
+is via $dbh->{'mysql_insertid'}. (Note we are using the $dbh in this case!)
 
 =item is_blob
 
